# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_databricks.config as config
    import pulumi_databricks.databricks as databricks
else:
    config = _utilities.lazy_import('pulumi_databricks.config')
    databricks = _utilities.lazy_import('pulumi_databricks.databricks')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "databricks",
  "mod": "databricks/awsS3Mount",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/awsS3Mount:AwsS3Mount": "AwsS3Mount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/azureAdlsGen1Mount",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/azureAdlsGen1Mount:AzureAdlsGen1Mount": "AzureAdlsGen1Mount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/azureAdlsGen2Mount",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/azureAdlsGen2Mount:AzureAdlsGen2Mount": "AzureAdlsGen2Mount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/azureBlobMount",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/azureBlobMount:AzureBlobMount": "AzureBlobMount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/azureDbfsFile",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/azureDbfsFile:AzureDbfsFile": "AzureDbfsFile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/catalog",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/cluster",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/clusterPolicy",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/clusterPolicy:ClusterPolicy": "ClusterPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/databricksMount",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/databricksMount:DatabricksMount": "DatabricksMount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/directory",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/globalInitScript",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/globalInitScript:GlobalInitScript": "GlobalInitScript"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/group",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/group:Group": "Group"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/groupInstanceProfile",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/groupInstanceProfile:GroupInstanceProfile": "GroupInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/groupMember",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/groupMember:GroupMember": "GroupMember"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/iPAccessList",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/iPAccessList:IPAccessList": "IPAccessList"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/instancePool",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/instancePool:InstancePool": "InstancePool"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/instanceProfile",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/instanceProfile:InstanceProfile": "InstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/job",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/job:Job": "Job"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mLFlowExperiment",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mLFlowExperiment:MLFlowExperiment": "MLFlowExperiment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mLFlowModel",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mLFlowModel:MLFlowModel": "MLFlowModel"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/metastore",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/metastore:Metastore": "Metastore"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/metastoreAssignment",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/metastoreAssignment:MetastoreAssignment": "MetastoreAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/metastoreDataAccess",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/metastoreDataAccess:MetastoreDataAccess": "MetastoreDataAccess"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsCredentials",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsCredentials:MwsCredentials": "MwsCredentials"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsCustomerManagedKeys",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsCustomerManagedKeys:MwsCustomerManagedKeys": "MwsCustomerManagedKeys"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsLogDelivery",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsLogDelivery:MwsLogDelivery": "MwsLogDelivery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsNetworks",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsNetworks:MwsNetworks": "MwsNetworks"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsPrivateAccessSettings",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsPrivateAccessSettings:MwsPrivateAccessSettings": "MwsPrivateAccessSettings"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsStorageConfigurations",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsStorageConfigurations:MwsStorageConfigurations": "MwsStorageConfigurations"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsVpcEndpoint",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsVpcEndpoint:MwsVpcEndpoint": "MwsVpcEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/mwsWorkspaces",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/mwsWorkspaces:MwsWorkspaces": "MwsWorkspaces"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/notebook",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/notebook:Notebook": "Notebook"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/oboToken",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/oboToken:OboToken": "OboToken"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/permissions",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/permissions:Permissions": "Permissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/pipeline",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/repo",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/repo:Repo": "Repo"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/schema",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/secret",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/secretAcl",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/secretAcl:SecretAcl": "SecretAcl"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/secretScope",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/secretScope:SecretScope": "SecretScope"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/servicePrincipal",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/servicePrincipal:ServicePrincipal": "ServicePrincipal"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlDashboard",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlDashboard:SqlDashboard": "SqlDashboard"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlEndpoint",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlEndpoint:SqlEndpoint": "SqlEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlGlobalConfig",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlGlobalConfig:SqlGlobalConfig": "SqlGlobalConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlPermissions",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlPermissions:SqlPermissions": "SqlPermissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlQuery",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlQuery:SqlQuery": "SqlQuery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlVisualization",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlVisualization:SqlVisualization": "SqlVisualization"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/sqlWidget",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/sqlWidget:SqlWidget": "SqlWidget"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/token",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/token:Token": "Token"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/user",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/user:User": "User"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/userInstanceProfile",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/userInstanceProfile:UserInstanceProfile": "UserInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "databricks/workspaceConf",
  "fqn": "pulumi_databricks.databricks",
  "classes": {
   "databricks:databricks/workspaceConf:WorkspaceConf": "WorkspaceConf"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "databricks",
  "token": "pulumi:providers:databricks",
  "fqn": "pulumi_databricks",
  "class": "Provider"
 }
]
"""
)
